***************
* REPLICATION FILE FOR "AID AND THE RISE AND FALL OF CONFLICT IN THE MUSLIM WORLD"
* Date: APRIL 2015
********************



* Set home directory to store data
* command: cd "FILE DIRECTORY"

***
set mem 500m
set matsize 5000
mata: mata set matafavor speed, perm
set more off



use AhmedWerker_QJPS.dta
* Regressions run in Stata/SE 13.1
log using AhmedWerker_analysis.log, replace

********************************************************
* MAIN FIGURES
********************************************************
* Figures 2-5 capture our key difference-in-difference figures (and corresponding statistics -- in Table 1)
* We summarize the data below, which we then plot appropriately in an excel spreadsheet. 
* For instance, we create 3 year moving averages and differences in the spreadsheet.
* An excel file with this data and chart is included in the replication file (which is also included in the replication file)

* Oil prices
tab year, sum(oilpriceus2009)

* For figures 2 and 3: Summary of aid in Muslim and non-Muslim countries
tab year if muslim==1, sum(aid)
tab year if muslim==0, sum(aid)

* For figures 4 and 5: Summary of civil war
* Low intensity civil war (at least 25 battle deaths)
tab year if muslim==1, sum(cwar)
tab year if muslim==0, sum(cwar)
* High intensity civil war (at least 1000 battle deaths)
tab year if muslim==1, sum(cwarhigh)


***********************************************************
* MAIN RESULTS
***********************************************************
* TABLE 1: Difference-in-difference estimates for conflict, by periods of low and high oil prices
* High intensity civil war
* Row 1: conflict in muslim and non-muslim countries
sum cwarhigh if muslim==1 & period4==1
sum cwarhigh if muslim==0 & period4==1
regress cwarhigh during muslim during_muslim if (period4==1 | period4==2), cluster(ccode)
* note: Coefficient on during_muslim is the diff-in-diff estimate in row 2
regress cwarhigh postoil muslim postoil_muslim if (period4==2 | period4==3), cluster(ccode)
* note: coefficient on postoil_muslim is diff-in-diff estimate in row 3
regress cwarhigh post2000 muslim post2000_muslim if (period4==3 | period4==4), cluster(ccode)
* note: coefficient on post2000_muslim is diff-in-diff estimate in row 4
regress cwarhigh muslim if period4==4, cluster(ccode)

*******
* TABLE 2
* OLS regressions: Columns 1-3
newey2 aid oilpriceus2009 codummy* if muslim, lag(1) force
newey2 aid oilpriceus2009 codummy* if muslim==0, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil

***
* 2SLS regressions (with accompanying first stage regression and F-statistics): Columns 4-11
* Column 4
newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force

* Column 5 - include remittances
newey2 cwarhigh (aid = muslimoil) remit_gdp lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil remit_gdp lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil

* Column 6 - include assassinations
newey2 cwarhigh (aid = muslimoil) assin lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil assin lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil

* Column 7 - include number of terrorist fatalities
newey2 cwarhigh (aid = muslimoil) nkill lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil nkill lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil

* Column 8 - Include post 2000 observatons with post-2000 adjuster
newey2 cwarhigh (aid = muslimoil muslimoil2000) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy*, lag(1) force
newey2 aid muslimoil muslimoil2000 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy*, lag(1) force
test muslimoil muslimoil2000 

* Column 9 - Estimate with aid per capita
newey2 cwarhigh (aidpc = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aidpc muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil

* Column 10 - Estimate with aid in levels
newey2 cwarhigh (aidmil = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aidmil muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil

* Column 11 - Estimate with aid in log levels
newey2 cwarhigh (lnaidmil = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 lnaidmil muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil


/*
* Table 2 - Robustness
* CLUSTER BY MUSLIM AND YEAR
ivreg cwarhigh (aid=muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil muslim_year ydum* codummy* if year<=2000, cluster(muslimyear)

* Exclude Lebanon, Morocco, and both
newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cname!="Lebanon", lag(1) force
newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cname!="Morocco", lag(1) force
newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cname!="Lebanon" & cname!="Morocco", lag(1) force


*/


*******
* TABLE 3: Alternate specifications
* Column 1 - IV probit (exclude FE otherwise will not converge, but control for constituent parts of instrument)
ivprobit cwarhigh (aid= muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil oilpriceus2009 muslim if year<=2000, cluster(ccode)

* Columns 2-4: Variation of country and year fixed effects
newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* muslim if year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* muslim if year<=2000, lag(1) force
test muslimoil

newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil oilpriceus2009 codummy* if year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil oilpriceus2009 codummy* if year<=2000, lag(1) force
test muslimoil

newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil oilpriceus2009 muslim if  year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil oilpriceus2009 muslim if year<=2000, lag(1) force
test muslimoil

* Columns 5-7: Lagged aid
newey2 cwarhigh (aid_lag1 = muslimoil_lag1) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid_lag1 muslimoil_lag1 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
test muslimoil_lag1

newey2 cwarhigh (aid_lag2 = muslimoil_lag2) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if  year<=2000, lag(1) force
newey2 aid_lag2 muslimoil_lag2 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
test muslimoil_lag2

newey2 cwarhigh (aid_lag4 = muslimoil_lag4) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid_lag4 muslimoil_lag4 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
test muslimoil_lag4

* Columns 8-9: Moving average of aid
newey2 cwarhigh (aid_ma2= muslimoil_ma2) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid_ma2 muslimoil_ma2 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if  year<=2000, lag(1) force
test muslimoil_ma2

newey2 cwarhigh (aid_ma4= muslimoil_ma4) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if  year<=2000, lag(1) force
newey2 aid_ma4 muslimoil_ma4 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
test muslimoil_ma4



********
* TABLE 4: Accounting for unobserved hetereogeneity and alternate classifications
* Column 1 - Control for Muslim x Cold War
newey2 cwarhigh (aid=muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil muslim_cw ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil muslim_cw ydum* codummy* if  year<=2000, lag(1) force
test muslimoil

* Column 2 - Control for Muslim x Year
newey2 cwarhigh (aid=muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil muslim_year ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil muslim_year ydum* codummy* if year<=2000, lag(1) force
test muslimoil

* Column 3 - Control for Region x Cold War
newey2 cwarhigh (aid=muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil africa_cw asia_cw meast_cw nam_cw sam_cw europe_cw ydum* codummy* if year<=2000, lag(1) force
* test africa_cw asia_cw meast_cw nam_cw sam_cw europe_cw
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil africa_cw asia_cw meast_cw nam_cw sam_cw europe_cw ydum* codummy* if year<=2000, lag(1) force
test muslimoil

* Column 4 - Control for Region x Year
newey2 cwarhigh (aid=muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil africa_year asia_year meast_year nam_year sam_year europe_year ydum* codummy* if year<=2000, lag(1) force
* test africa_year asia_year meast_year nam_year sam_year europe_year
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil africa_year asia_year meast_year nam_year sam_year europe_year ydum* codummy* if year<=2000, lag(1) force
test muslimoil

* Column 5 - All conflict (Internationalized and non-internationalized conflict)
newey2 cwarhighall (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
test muslimoil

* Columns 6-8: Instrument with alternate thresholds for Muslim country classification
newey2 cwarhigh (aid = muslimoil60) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil60 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil60

newey2 cwarhigh (aid = muslimoil80) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil80 lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoil80

* instrument with percent muslim from Fearon and Laitin (2003)
newey2 cwarhigh (aid = muslimoilfl) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoilfl lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & cwarhigh!=., lag(1) force
test muslimoilfl

* Columns 9-10: Civil war onset
newey2 cwarhigh_onset (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
test muslimoil

* aid reduces conflict onset in the year FOLLOWING a drop in aid (i.e., dtaid<0)
newey2 cwarhigh_onset (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & dtaid<0, lag(1) force
newey2 aid muslimoil lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000 & dtaid<0, lag(1) force
test muslimoil


*****
* TABLE 5: Diff-in-diff, accounting for alternate explanations
* Column 1: Controll for remittances
regress cwarhigh during muslim during_muslim remit_gdp if (period4==1 | period4==2), cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim remit_gdp if (period4==2 | period4==3), cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim remit_gdp if (period4==3 | period4==4), cluster(ccode)

* Column 2: Exclude Lebanon
regress cwarhigh during muslim during_muslim if (period4==1 | period4==2) & cname!="Lebanon", cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim if (period4==2 | period4==3) & cname!="Lebanon", cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim if (period4==3 | period4==4) & cname!="Lebanon", cluster(ccode)

* Column 3: Exclude Morocco
regress cwarhigh during muslim during_muslim if (period4==1 | period4==2) & cname!="Morocco", cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim if (period4==2 | period4==3) & cname!="Morocco", cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim if (period4==3 | period4==4) & cname!="Morocco", cluster(ccode)

* Column 4: Exclude Lebanon and Morocco
regress cwarhigh during muslim during_muslim if (period4==1 | period4==2) & cname!="Morocco" & cname!="Lebanon", cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim if (period4==2 | period4==3) & cname!="Morocco" & cname!="Lebanon", cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim if (period4==3 | period4==4) & cname!="Morocco" & cname!="Lebanon", cluster(ccode)

* Column 5: Control for assassinations
regress cwarhigh during muslim during_muslim assin if (period4==1 | period4==2), cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim assin if (period4==2 | period4==3), cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim assin if (period4==3 | period4==4), cluster(ccode)

* Column 6: Control for number of terrorist fatalities
regress cwarhigh during muslim during_muslim nkill if (period4==1 | period4==2), cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim nkill if (period4==2 | period4==3), cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim nkill if (period4==3 | period4==4), cluster(ccode)



*************************
* APPENDIX TABLES 
*************************
* Table A3: Summary statistics
newey2 cwarhigh (aid = muslimoil) lngdpcap ggdpcap lnpop ruraloil LP72oil ydum* codummy* if year<=2000, lag(1) force
gen ivsample=e(sample)

sum cwarhigh aid oilpriceus2009 muslim lngdpcap ggdpcap lnpop rural72 polity72 if ivsample 

* Table A2: Sample of countries
* List of countries
tab cname if ivsample
tab cname if ivsample==1 & muslim==1



* Table A4: Pre-treatment characteristics - Political and economic conditions in Muslim and non-Muslim non-oil producers in 1972
ttest lngdpcap if year==1972, by(muslim)
ttest aid if year==1972, by(muslim)
ttest polity72 if year==1972, by(muslim)
ttest xconst if year==1972, by(muslim)
ttest rural72 if year==1972, by(muslim)
ttest cwar if year==1972, by(muslim)


* Table A5: Difference-in-difference estimates for foreign aid (% GDP)
regress aid during muslim during_muslim if (period4==1 | period4==2), cluster(ccode)
regress aid postoil muslim postoil_muslim if (period4==2 | period4==3), cluster(ccode)
regress aid post2000 muslim post2000_muslim if (period4==3 | period4==4), cluster(ccode)
regress aid muslim if period4==4, cluster(ccode)


* Table A6: Difference-in-difference estimates for civil war, accounting for differential trends
* Column 1: Civil war, with Muslim x Year trend
regress cwarhigh during muslim during_muslim muslim_year if (period4==1 | period4==2), cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim muslim_year if (period4==2 | period4==3), cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim muslim_year if (period4==3 | period4==4), cluster(ccode)

* Column 2: Civil war, with Region FE x Year trends
regress cwarhigh during muslim during_muslim africa_year asia_year meast_year nam_year sam_year europe_year if (period4==1 | period4==2), cluster(ccode)
regress cwarhigh postoil muslim postoil_muslim africa_year asia_year meast_year nam_year sam_year europe_year if (period4==2 | period4==3), cluster(ccode)
regress cwarhigh post2000 muslim post2000_muslim africa_year asia_year meast_year nam_year sam_year europe_year if (period4==3 | period4==4), cluster(ccode)








*********






